@@ -1,138 +1,29 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
 #[link(name = "windows")]
 extern "system" {
+    #[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
     pub fn MLCreateOperatorRegistry(registry: *mut IMLOperatorRegistry) -> ::windows_sys::core::HRESULT;
+    #[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
     pub fn WinMLCreateRuntime(runtime: *mut IWinMLRuntime) -> ::windows_sys::core::HRESULT;
 }
-#[repr(transparent)]
-pub struct IMLOperatorAttributes(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IMLOperatorAttributes {}
-impl ::core::clone::Clone for IMLOperatorAttributes {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IMLOperatorKernel(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IMLOperatorKernel {}
-impl ::core::clone::Clone for IMLOperatorKernel {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IMLOperatorKernelContext(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IMLOperatorKernelContext {}
-impl ::core::clone::Clone for IMLOperatorKernelContext {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IMLOperatorKernelCreationContext(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IMLOperatorKernelCreationContext {}
-impl ::core::clone::Clone for IMLOperatorKernelCreationContext {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IMLOperatorKernelFactory(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IMLOperatorKernelFactory {}
-impl ::core::clone::Clone for IMLOperatorKernelFactory {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IMLOperatorRegistry(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IMLOperatorRegistry {}
-impl ::core::clone::Clone for IMLOperatorRegistry {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IMLOperatorShapeInferenceContext(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IMLOperatorShapeInferenceContext {}
-impl ::core::clone::Clone for IMLOperatorShapeInferenceContext {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IMLOperatorShapeInferrer(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IMLOperatorShapeInferrer {}
-impl ::core::clone::Clone for IMLOperatorShapeInferrer {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IMLOperatorTensor(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IMLOperatorTensor {}
-impl ::core::clone::Clone for IMLOperatorTensor {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IMLOperatorTensorShapeDescription(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IMLOperatorTensorShapeDescription {}
-impl ::core::clone::Clone for IMLOperatorTensorShapeDescription {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IMLOperatorTypeInferenceContext(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IMLOperatorTypeInferenceContext {}
-impl ::core::clone::Clone for IMLOperatorTypeInferenceContext {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IMLOperatorTypeInferrer(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IMLOperatorTypeInferrer {}
-impl ::core::clone::Clone for IMLOperatorTypeInferrer {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IWinMLEvaluationContext(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IWinMLEvaluationContext {}
-impl ::core::clone::Clone for IWinMLEvaluationContext {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IWinMLModel(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IWinMLModel {}
-impl ::core::clone::Clone for IWinMLModel {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IWinMLRuntime(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IWinMLRuntime {}
-impl ::core::clone::Clone for IWinMLRuntime {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct IWinMLRuntimeFactory(pub *mut ::core::ffi::c_void);
-impl ::core::marker::Copy for IWinMLRuntimeFactory {}
-impl ::core::clone::Clone for IWinMLRuntimeFactory {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
+pub type IMLOperatorAttributes = *mut ::core::ffi::c_void;
+pub type IMLOperatorKernel = *mut ::core::ffi::c_void;
+pub type IMLOperatorKernelContext = *mut ::core::ffi::c_void;
+pub type IMLOperatorKernelCreationContext = *mut ::core::ffi::c_void;
+pub type IMLOperatorKernelFactory = *mut ::core::ffi::c_void;
+pub type IMLOperatorRegistry = *mut ::core::ffi::c_void;
+pub type IMLOperatorShapeInferenceContext = *mut ::core::ffi::c_void;
+pub type IMLOperatorShapeInferrer = *mut ::core::ffi::c_void;
+pub type IMLOperatorTensor = *mut ::core::ffi::c_void;
+pub type IMLOperatorTensorShapeDescription = *mut ::core::ffi::c_void;
+pub type IMLOperatorTypeInferenceContext = *mut ::core::ffi::c_void;
+pub type IMLOperatorTypeInferrer = *mut ::core::ffi::c_void;
+pub type IWinMLEvaluationContext = *mut ::core::ffi::c_void;
+pub type IWinMLModel = *mut ::core::ffi::c_void;
+pub type IWinMLRuntime = *mut ::core::ffi::c_void;
+pub type IWinMLRuntimeFactory = *mut ::core::ffi::c_void;
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct MLOperatorAttribute {
     pub name: super::super::super::Foundation::PSTR,
@@ -148,6 +39,7 @@ impl ::core::clone::Clone for MLOperatorAttribute {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct MLOperatorAttributeNameValue {
     pub name: super::super::super::Foundation::PSTR,
@@ -164,6 +56,7 @@ impl ::core::clone::Clone for MLOperatorAttributeNameValue {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union MLOperatorAttributeNameValue_0 {
     pub reserved: *mut ::core::ffi::c_void,
@@ -179,6 +72,7 @@ impl ::core::clone::Clone for MLOperatorAttributeNameValue_0 {
         *self
     }
 }
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 #[repr(transparent)]
 pub struct MLOperatorAttributeType(pub u32);
 impl MLOperatorAttributeType {
@@ -197,6 +91,7 @@ impl ::core::clone::Clone for MLOperatorAttributeType {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 pub struct MLOperatorEdgeDescription {
     pub edgeType: MLOperatorEdgeType,
     pub Anonymous: MLOperatorEdgeDescription_0,
@@ -208,6 +103,7 @@ impl ::core::clone::Clone for MLOperatorEdgeDescription {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 pub union MLOperatorEdgeDescription_0 {
     pub reserved: u64,
     pub tensorDataType: MLOperatorTensorDataType,
@@ -218,6 +114,7 @@ impl ::core::clone::Clone for MLOperatorEdgeDescription_0 {
         *self
     }
 }
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 #[repr(transparent)]
 pub struct MLOperatorEdgeType(pub u32);
 impl MLOperatorEdgeType {
@@ -231,6 +128,7 @@ impl ::core::clone::Clone for MLOperatorEdgeType {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct MLOperatorEdgeTypeConstraint {
     pub typeLabel: super::super::super::Foundation::PSTR,
@@ -245,6 +143,7 @@ impl ::core::clone::Clone for MLOperatorEdgeTypeConstraint {
         *self
     }
 }
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 #[repr(transparent)]
 pub struct MLOperatorExecutionType(pub u32);
 impl MLOperatorExecutionType {
@@ -259,6 +158,7 @@ impl ::core::clone::Clone for MLOperatorExecutionType {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct MLOperatorKernelDescription {
     pub domain: super::super::super::Foundation::PSTR,
@@ -280,6 +180,7 @@ impl ::core::clone::Clone for MLOperatorKernelDescription {
         *self
     }
 }
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 #[repr(transparent)]
 pub struct MLOperatorKernelOptions(pub u32);
 impl MLOperatorKernelOptions {
@@ -292,6 +193,7 @@ impl ::core::clone::Clone for MLOperatorKernelOptions {
         *self
     }
 }
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 #[repr(transparent)]
 pub struct MLOperatorParameterOptions(pub u32);
 impl MLOperatorParameterOptions {
@@ -306,6 +208,7 @@ impl ::core::clone::Clone for MLOperatorParameterOptions {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct MLOperatorSchemaDescription {
     pub name: super::super::super::Foundation::PSTR,
@@ -330,6 +233,7 @@ impl ::core::clone::Clone for MLOperatorSchemaDescription {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct MLOperatorSchemaEdgeDescription {
     pub options: MLOperatorParameterOptions,
@@ -345,6 +249,7 @@ impl ::core::clone::Clone for MLOperatorSchemaEdgeDescription {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union MLOperatorSchemaEdgeDescription_0 {
     pub reserved: *mut ::core::ffi::c_void,
@@ -359,6 +264,7 @@ impl ::core::clone::Clone for MLOperatorSchemaEdgeDescription_0 {
         *self
     }
 }
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 #[repr(transparent)]
 pub struct MLOperatorSchemaEdgeTypeFormat(pub i32);
 impl MLOperatorSchemaEdgeTypeFormat {
@@ -372,6 +278,7 @@ impl ::core::clone::Clone for MLOperatorSchemaEdgeTypeFormat {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct MLOperatorSetId {
     pub domain: super::super::super::Foundation::PSTR,
@@ -385,6 +292,7 @@ impl ::core::clone::Clone for MLOperatorSetId {
         *self
     }
 }
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 #[repr(transparent)]
 pub struct MLOperatorTensorDataType(pub u32);
 impl MLOperatorTensorDataType {
@@ -412,6 +320,7 @@ impl ::core::clone::Clone for MLOperatorTensorDataType {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation', 'Win32_Graphics_Direct3D12'*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Graphics_Direct3D12"))]
 pub struct WINML_BINDING_DESC {
     pub Name: super::super::super::Foundation::PWSTR,
@@ -427,6 +336,7 @@ impl ::core::clone::Clone for WINML_BINDING_DESC {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation', 'Win32_Graphics_Direct3D12'*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Graphics_Direct3D12"))]
 pub union WINML_BINDING_DESC_0 {
     pub Tensor: WINML_TENSOR_BINDING_DESC,
@@ -443,34 +353,34 @@ impl ::core::clone::Clone for WINML_BINDING_DESC_0 {
         *self
     }
 }
-#[repr(transparent)]
-pub struct WINML_BINDING_TYPE(pub i32);
-pub const WINML_BINDING_UNDEFINED: WINML_BINDING_TYPE = WINML_BINDING_TYPE(0i32);
-pub const WINML_BINDING_TENSOR: WINML_BINDING_TYPE = WINML_BINDING_TYPE(1i32);
-pub const WINML_BINDING_SEQUENCE: WINML_BINDING_TYPE = WINML_BINDING_TYPE(2i32);
-pub const WINML_BINDING_MAP: WINML_BINDING_TYPE = WINML_BINDING_TYPE(3i32);
-pub const WINML_BINDING_IMAGE: WINML_BINDING_TYPE = WINML_BINDING_TYPE(4i32);
-pub const WINML_BINDING_RESOURCE: WINML_BINDING_TYPE = WINML_BINDING_TYPE(5i32);
-impl ::core::marker::Copy for WINML_BINDING_TYPE {}
-impl ::core::clone::Clone for WINML_BINDING_TYPE {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[repr(transparent)]
-pub struct WINML_FEATURE_TYPE(pub i32);
-pub const WINML_FEATURE_UNDEFINED: WINML_FEATURE_TYPE = WINML_FEATURE_TYPE(0i32);
-pub const WINML_FEATURE_TENSOR: WINML_FEATURE_TYPE = WINML_FEATURE_TYPE(1i32);
-pub const WINML_FEATURE_SEQUENCE: WINML_FEATURE_TYPE = WINML_FEATURE_TYPE(2i32);
-pub const WINML_FEATURE_MAP: WINML_FEATURE_TYPE = WINML_FEATURE_TYPE(3i32);
-pub const WINML_FEATURE_IMAGE: WINML_FEATURE_TYPE = WINML_FEATURE_TYPE(4i32);
-impl ::core::marker::Copy for WINML_FEATURE_TYPE {}
-impl ::core::clone::Clone for WINML_FEATURE_TYPE {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub type WINML_BINDING_TYPE = i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_BINDING_UNDEFINED: WINML_BINDING_TYPE = 0i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_BINDING_TENSOR: WINML_BINDING_TYPE = 1i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_BINDING_SEQUENCE: WINML_BINDING_TYPE = 2i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_BINDING_MAP: WINML_BINDING_TYPE = 3i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_BINDING_IMAGE: WINML_BINDING_TYPE = 4i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_BINDING_RESOURCE: WINML_BINDING_TYPE = 5i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub type WINML_FEATURE_TYPE = i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_FEATURE_UNDEFINED: WINML_FEATURE_TYPE = 0i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_FEATURE_TENSOR: WINML_FEATURE_TYPE = 1i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_FEATURE_SEQUENCE: WINML_FEATURE_TYPE = 2i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_FEATURE_MAP: WINML_FEATURE_TYPE = 3i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_FEATURE_IMAGE: WINML_FEATURE_TYPE = 4i32;
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 pub struct WINML_IMAGE_BINDING_DESC {
     pub ElementType: WINML_TENSOR_DATA_TYPE,
     pub NumDimensions: u32,
@@ -485,6 +395,7 @@ impl ::core::clone::Clone for WINML_IMAGE_BINDING_DESC {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 pub struct WINML_IMAGE_VARIABLE_DESC {
     pub ElementType: WINML_TENSOR_DATA_TYPE,
     pub NumDimensions: u32,
@@ -497,6 +408,7 @@ impl ::core::clone::Clone for WINML_IMAGE_VARIABLE_DESC {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct WINML_MAP_BINDING_DESC {
     pub ElementCount: u32,
@@ -514,6 +426,7 @@ impl ::core::clone::Clone for WINML_MAP_BINDING_DESC {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union WINML_MAP_BINDING_DESC_0 {
     pub pStringKeys: *mut super::super::super::Foundation::PWSTR,
@@ -528,6 +441,7 @@ impl ::core::clone::Clone for WINML_MAP_BINDING_DESC_0 {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union WINML_MAP_BINDING_DESC_1 {
     pub pStringFields: *mut super::super::super::Foundation::PWSTR,
@@ -544,6 +458,7 @@ impl ::core::clone::Clone for WINML_MAP_BINDING_DESC_1 {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 pub struct WINML_MAP_VARIABLE_DESC {
     pub KeyType: WINML_TENSOR_DATA_TYPE,
     pub Fields: WINML_TENSOR_DATA_TYPE,
@@ -555,6 +470,7 @@ impl ::core::clone::Clone for WINML_MAP_VARIABLE_DESC {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct WINML_MODEL_DESC {
     pub Author: super::super::super::Foundation::PWSTR,
@@ -572,6 +488,7 @@ impl ::core::clone::Clone for WINML_MODEL_DESC {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Graphics_Direct3D12'*"]
 #[cfg(feature = "Win32_Graphics_Direct3D12")]
 pub struct WINML_RESOURCE_BINDING_DESC {
     pub ElementType: WINML_TENSOR_DATA_TYPE,
@@ -587,16 +504,12 @@ impl ::core::clone::Clone for WINML_RESOURCE_BINDING_DESC {
         *self
     }
 }
-#[repr(transparent)]
-pub struct WINML_RUNTIME_TYPE(pub i32);
-pub const WINML_RUNTIME_CNTK: WINML_RUNTIME_TYPE = WINML_RUNTIME_TYPE(0i32);
-impl ::core::marker::Copy for WINML_RUNTIME_TYPE {}
-impl ::core::clone::Clone for WINML_RUNTIME_TYPE {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub type WINML_RUNTIME_TYPE = i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_RUNTIME_CNTK: WINML_RUNTIME_TYPE = 0i32;
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct WINML_SEQUENCE_BINDING_DESC {
     pub ElementCount: u32,
@@ -612,6 +525,7 @@ impl ::core::clone::Clone for WINML_SEQUENCE_BINDING_DESC {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union WINML_SEQUENCE_BINDING_DESC_0 {
     pub pStrings: *mut super::super::super::Foundation::PWSTR,
@@ -628,6 +542,7 @@ impl ::core::clone::Clone for WINML_SEQUENCE_BINDING_DESC_0 {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 pub struct WINML_SEQUENCE_VARIABLE_DESC {
     pub ElementType: WINML_TENSOR_DATA_TYPE,
 }
@@ -638,6 +553,7 @@ impl ::core::clone::Clone for WINML_SEQUENCE_VARIABLE_DESC {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 pub struct WINML_TENSOR_BINDING_DESC {
     pub DataType: WINML_TENSOR_DATA_TYPE,
     pub NumDimensions: u32,
@@ -651,32 +567,44 @@ impl ::core::clone::Clone for WINML_TENSOR_BINDING_DESC {
         *self
     }
 }
-#[repr(transparent)]
-pub struct WINML_TENSOR_DATA_TYPE(pub i32);
-pub const WINML_TENSOR_UNDEFINED: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(0i32);
-pub const WINML_TENSOR_FLOAT: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(1i32);
-pub const WINML_TENSOR_UINT8: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(2i32);
-pub const WINML_TENSOR_INT8: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(3i32);
-pub const WINML_TENSOR_UINT16: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(4i32);
-pub const WINML_TENSOR_INT16: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(5i32);
-pub const WINML_TENSOR_INT32: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(6i32);
-pub const WINML_TENSOR_INT64: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(7i32);
-pub const WINML_TENSOR_STRING: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(8i32);
-pub const WINML_TENSOR_BOOLEAN: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(9i32);
-pub const WINML_TENSOR_FLOAT16: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(10i32);
-pub const WINML_TENSOR_DOUBLE: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(11i32);
-pub const WINML_TENSOR_UINT32: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(12i32);
-pub const WINML_TENSOR_UINT64: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(13i32);
-pub const WINML_TENSOR_COMPLEX64: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(14i32);
-pub const WINML_TENSOR_COMPLEX128: WINML_TENSOR_DATA_TYPE = WINML_TENSOR_DATA_TYPE(15i32);
-impl ::core::marker::Copy for WINML_TENSOR_DATA_TYPE {}
-impl ::core::clone::Clone for WINML_TENSOR_DATA_TYPE {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub type WINML_TENSOR_DATA_TYPE = i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_UNDEFINED: WINML_TENSOR_DATA_TYPE = 0i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_FLOAT: WINML_TENSOR_DATA_TYPE = 1i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_UINT8: WINML_TENSOR_DATA_TYPE = 2i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_INT8: WINML_TENSOR_DATA_TYPE = 3i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_UINT16: WINML_TENSOR_DATA_TYPE = 4i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_INT16: WINML_TENSOR_DATA_TYPE = 5i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_INT32: WINML_TENSOR_DATA_TYPE = 6i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_INT64: WINML_TENSOR_DATA_TYPE = 7i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_STRING: WINML_TENSOR_DATA_TYPE = 8i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_BOOLEAN: WINML_TENSOR_DATA_TYPE = 9i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_FLOAT16: WINML_TENSOR_DATA_TYPE = 10i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_DOUBLE: WINML_TENSOR_DATA_TYPE = 11i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_UINT32: WINML_TENSOR_DATA_TYPE = 12i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_UINT64: WINML_TENSOR_DATA_TYPE = 13i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_COMPLEX64: WINML_TENSOR_DATA_TYPE = 14i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
+pub const WINML_TENSOR_COMPLEX128: WINML_TENSOR_DATA_TYPE = 15i32;
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 pub const WINML_TENSOR_DIMENSION_COUNT_MAX: u32 = 4u32;
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML'*"]
 pub struct WINML_TENSOR_VARIABLE_DESC {
     pub ElementType: WINML_TENSOR_DATA_TYPE,
     pub NumDimensions: u32,
@@ -689,6 +617,7 @@ impl ::core::clone::Clone for WINML_TENSOR_VARIABLE_DESC {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct WINML_VARIABLE_DESC {
     pub Name: super::super::super::Foundation::PWSTR,
@@ -706,6 +635,7 @@ impl ::core::clone::Clone for WINML_VARIABLE_DESC {
     }
 }
 #[repr(C)]
+#[doc = "*Required features: 'Win32_AI_MachineLearning_WinML', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union WINML_VARIABLE_DESC_0 {
     pub Tensor: WINML_TENSOR_VARIABLE_DESC,
